@@ -13,8 +13,8 @@
 #include "viewer/viewcontainer.h"
 
 #include <KActionCollection>
-#include <kbookmarks_version.h>
 #include <KBookmarkMenu>
+
 #include <QMenu>
 #include <QStandardPaths>
 
@@ -35,12 +35,8 @@ m_mainWindow(mainWindow)
     manager->setEditorOptions(i18n("Konversation Bookmarks Editor"), false);
     manager->setUpdate( true );
 
-#if KBOOKMARKS_VERSION < QT_VERSION_CHECK(5, 69, 0)
-    m_bookmarkMenu = new KBookmarkMenu(manager, this, menu, m_mainWindow->actionCollection());
-#else
     m_bookmarkMenu = new KBookmarkMenu(manager, this, menu);
     m_mainWindow->actionCollection()->addActions(menu->actions());
-#endif
 }
 
 KonviBookmarkHandler::~KonviBookmarkHandler()
