@@ -40,6 +40,17 @@ Preferences *Preferences::self()
 
 Preferences::Preferences()
 {
+    // kconfigcompiler 5.91 cannot generate code with signals for ItemAccessors=true
+    // manually add the item for now
+    setCurrentGroup(QStringLiteral("LauncherEntry"));
+
+    auto notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&Preferences::itemChanged);
+
+    auto* innerItemShowLauncherEntryCount = new KConfigSkeleton::ItemBool(currentGroup(), QStringLiteral("ShowLauncherEntryCount"), mShowLauncherEntryCount, true);
+    mShowLauncherEntryCountItem = new KConfigCompilerSignallingItem(innerItemShowLauncherEntryCount, this, notifyFunction, signalShowLauncherEntryCountChanged);
+    addItem(mShowLauncherEntryCountItem);
+    // end manual item addition
+
     // create default identity
     mIdentity=new Identity();
     mIdentity->setName(i18n("Default Identity"));
@@ -429,31 +440,6 @@ void Preferences::setAutoUserhost(bool state)
     self()->PreferencesBase::setAutoUserhost(state);
 }
 
-bool Preferences::dialogFlag(const QString& flagName)
-{
-    KConfigGroup config(KSharedConfig::openConfig()->group("Notification self()->Messages"));
-
-    if (!config.readEntry(flagName).isEmpty())
-        return false;
-    else
-        return true;
-}
-
-void Preferences::setDialogFlag(const QString& flagName,bool state)
-{
-    KConfigGroup config(KSharedConfig::openConfig()->group("Notification self()->Messages"));
-
-    if (state)
-        config.deleteEntry(flagName);
-    else
-    {
-        if (config.readEntry(flagName).isEmpty())
-            config.writeEntry(flagName,"no");
-    }
-
-    config.sync();
-}
-
 
 // Channel Encodings
 const QString Preferences::channelEncoding(const QString& server,const QString& channel)
@@ -612,3 +598,40 @@ void Preferences::slotSetUseOSD(bool use)
 }
 
 
+void Preferences::setShowLauncherEntryCount(bool value)
+{
+    if ((value != mShowLauncherEntryCount) && !isShowLauncherEntryCountImmutable()) {
+        mShowLauncherEntryCount = value;
+        mSettingsChanged |= signalShowLauncherEntryCountChanged;
+    }
+}
+
+bool Preferences::showLauncherEntryCount() const
+{
+    return mShowLauncherEntryCount;
+}
+
+bool Preferences::isShowLauncherEntryCountImmutable() const
+{
+    return isImmutable(QStringLiteral("ShowLauncherEntryCount"));
+}
+
+bool Preferences::usrSave()
+{
+    if (!PreferencesBase::usrSave()) {
+        return false;
+    }
+
+    if (mSettingsChanged & signalShowLauncherEntryCountChanged) {
+        Q_EMIT showLauncherEntryCountChanged(mShowLauncherEntryCount);
+    }
+
+    mSettingsChanged = 0;
+
+    return true;
+}
+
+void Preferences::itemChanged(quint64 flags)
+{
+    mSettingsChanged |= flags;
+}
