@@ -8,8 +8,6 @@
 #include "application.h"
 #include "version.h"
 
-#include <QMutex>
-#include <QWaitCondition>
 #include <QCommandLineParser>
 
 #include <KAboutData>
@@ -17,6 +15,8 @@
 #include <Kdelibs4ConfigMigrator>
 #include <KDBusService>
 
+#include <chrono>
+#include <thread>
 
 int main(int argc, char* argv[])
 {
@@ -121,10 +121,7 @@ int main(int argc, char* argv[])
 
         if (ok)
         {
-            QMutex dummy;
-            dummy.lock();
-            QWaitCondition waitCondition;
-            waitCondition.wait(&dummy, delay);
+            std::this_thread::sleep_for(std::chrono::milliseconds(delay));
         }
     }
 
@@ -148,6 +145,9 @@ int main(int argc, char* argv[])
     QObject::connect(&dbusService, &KDBusService::activateRequested,
                      &app, &Application::handleActivate,
                      Qt::DirectConnection);
+    QObject::connect(&dbusService, &KDBusService::openRequested,
+                     &app, &Application::handleOpen,
+                     Qt::DirectConnection);
 
     return QApplication::exec();
 }
